@@ -21,7 +21,6 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-
 import asyncio
 import logging
 
@@ -138,6 +137,7 @@ class Client:
         "cache_max_size",
         "stats_max_size",
         "http",
+        "realtime",
         "_ready",
         "correct_tags",
         "load_game_data",
@@ -166,6 +166,7 @@ class Client:
         cache_max_size: int = 10000,
         stats_max_size: int = 1000,
         load_game_data: LoadGameData = LoadGameData(default=True),
+        realtime = False,
         **_,
     ):
 
@@ -186,6 +187,7 @@ class Client:
         self.stats_max_size = stats_max_size
 
         self.http = None  # set in method login()
+        self.realtime = realtime
         self.correct_tags = correct_tags
         self.load_game_data = load_game_data
 
@@ -255,8 +257,8 @@ class Client:
         self.http = http = self._create_client(email, password)
         await http.create_session(self.connector, self.timeout)
         await http.initialise_keys()
-        self._create_holders()
 
+        self._create_holders()
         LOG.debug("HTTP connection created. Client is ready for use.")
 
     def login_with_keys(self, *keys: str) -> None:
@@ -275,13 +277,10 @@ class Client:
 
         LOG.debug("HTTP connection created. Client is ready for use.")
 
-    def close(self) -> None:
-        """Closes the HTTP connection
-        """
-        LOG.info("Clash of Clans client logging out...")
-        self.dispatch("on_client_close")
-        self.loop.run_until_complete(self.http.close())
-        self.loop.close()
+    async def close(self) -> None:
+        """Closes the HTTP connection from within a loop function such as
+        async def main()"""
+        await self.http.close()
 
     def dispatch(self, event_name: str, *args, **kwargs) -> None:
         """Dispatches an event listener matching the `event_name` parameter."""
@@ -586,7 +585,12 @@ class Client:
             clan_tag = correct_tag(clan_tag)
 
         try:
-            data = await self.http.get_clan_current_war(clan_tag)
+            realtime = kwargs.get("realtime")
+        except KeyError:
+            realtime = None
+
+        try:
+            data = await self.http.get_clan_current_war(clan_tag, realtime=realtime)
         except Forbidden as exception:
             raise PrivateWarLog(exception.response, exception.reason) from exception
 
@@ -693,7 +697,12 @@ class Client:
             clan_tag = correct_tag(clan_tag)
 
         try:
-            data = await self.http.get_clan_war_league_group(clan_tag)
+            realtime = kwargs.get("realtime")
+        except KeyError:
+            realtime = None
+
+        try:
+            data = await self.http.get_clan_war_league_group(clan_tag, realtime=realtime)
         except Forbidden as exception:
             raise PrivateWarLog(exception.response, exception.reason) from exception
         except asyncio.TimeoutError:
@@ -741,7 +750,12 @@ class Client:
             war_tag = correct_tag(war_tag)
 
         try:
-            data = await self.http.get_cwl_wars(war_tag)
+            realtime = kwargs.get("realtime")
+        except KeyError:
+            realtime = None
+
+        try:
+            data = await self.http.get_cwl_wars(war_tag, realtime=realtime)
         except Forbidden as exception:
             raise PrivateWarLog(exception.response, exception.reason) from exception
 
@@ -869,7 +883,7 @@ class Client:
             return get_war
 
         try:
-            league_group = await self.get_league_group(clan_tag)
+            league_group = await self.get_league_group(clan_tag,**kwargs)
         except (NotFound, GatewayError) as exception:
             # either they're not in cwl (NotFound)
             # or it's an API bug where league group endpoint will timeout when the clan is searching (GatewayError)
